@@ -4,19 +4,20 @@
 import os
 
 from .output import out
-from .util import getImageObject, normaliseURL, unquote, strsize, getDirname, getFilename
+from .util import getImageObject, normaliseURL, unquote, getDirname, getFilename, writeFile
 from .events import getHandler
 
 class ComicStrip(object):
     """A list of comic image URLs."""
 
-    def __init__(self, name, stripUrl, imageUrls, namer, session):
+    def __init__(self, name, stripUrl, imageUrls, namer, session, text=None):
         """Store the image URL list."""
         self.name = name
         self.stripUrl = stripUrl
         self.imageUrls = imageUrls
         self.namer = namer
         self.session = session
+        self.text = text
 
     def getImages(self):
         """Get a list of image downloaders."""
@@ -29,7 +30,7 @@ class ComicStrip(object):
         if filename is None:
             filename = url.rsplit('/', 1)[1]
         dirname = getDirname(self.name)
-        return ComicImage(self.name, url, self.stripUrl, dirname, filename, self.session)
+        return ComicImage(self.name, url, self.stripUrl, dirname, filename, self.session, text=self.text)
 
 
 class ComicImage(object):
@@ -37,7 +38,7 @@ class ComicImage(object):
 
     ChunkBytes = 1024 * 100 # 100KB
 
-    def __init__(self, name, url, referrer, dirname, filename, session):
+    def __init__(self, name, url, referrer, dirname, filename, session, text=None):
         """Set URL and filename."""
         self.name = name
         self.referrer = referrer
@@ -46,6 +47,7 @@ class ComicImage(object):
         filename = getFilename(filename)
         self.filename, self.ext = os.path.splitext(filename)
         self.session = session
+        self.text = text
 
     def connect(self):
         """Connect to host and get meta information."""
@@ -83,20 +85,11 @@ class ComicImage(object):
             out.warn(u"Empty content from %s, try again..." % self.url)
             self.connect()
             content = self.urlobj.content
-        try:
-            out.debug(u'Writing comic to file %s...' % fn)
-            with open(fn, 'wb') as comicOut:
-                comicOut.write(content)
-                comicOut.flush()
-                os.fsync(comicOut.fileno())
-            size = os.path.getsize(fn)
-            if size == 0:
-                raise OSError("empty file %s" % fn)
-        except Exception:
-            if os.path.isfile(fn):
-                os.remove(fn)
-            raise
-        else:
-            out.info(u"Saved %s (%s)." % (fn, strsize(size)))
-            getHandler().comicDownloaded(self, fn)
+        out.debug(u'Writing comic to file %s...' % fn)
+        writeFile(fn, content)
+        if self.text:
+            fntext = os.path.join(comicDir, "%s.txt" % self.filename)
+            out.debug(u'Writing comic text to file %s...' % fntext)
+            writeFile(fntext, self.text, encoding='utf-8')
+        getHandler().comicDownloaded(self, fn, text=self.text)
         return fn, True
