@@ -38,6 +38,7 @@ class AbstruseGoose(_BasicScraper):
     imageSearch = compile(tagre('img', 'src', r'(%sstrips/[^<>"]+)' % rurl))
     prevSearch = compile(tagre('a', 'href', r'(%s\d+)' % rurl) + r'&laquo; Previous</a>')
     help = 'Index format: n (unpadded)'
+    textSearch = compile(tagre("img", "title", r'([^"]+)'))
 
     @classmethod
     def namer(cls, imageUrl, pageUrl):
@@ -66,15 +67,6 @@ class Achewood(_BasicScraper):
     namer = regexNamer(compile(r'date=(\d+)'))
 
 
-class AetheriaEpics(_BasicScraper):
-    url = 'http://aetheria-epics.schala.net/'
-    stripUrl = url + '%s.html'
-    firstStripUrl = stripUrl % '00001'
-    imageSearch = compile(tagre("img", "src", r'(\d{5}\.jpg)'))
-    prevSearch = compile(tagre("a", "href", r'(\d{5}\.html)') + "Previous")
-    help = 'Index format: nnn'
-
-
 class AfterStrife(_BasicScraper):
     baseUrl = 'http://afterstrife.com/'
     rurl = escape(baseUrl)
@@ -172,7 +164,7 @@ class AllTheGrowingThings(_BasicScraper):
     rurl = escape(url)
     stripUrl = url + '%s/'
     firstStripUrl = stripUrl % '2009/04/21/all-the-growing-things'
-    imageSearch = compile(tagre("img", "src", r'(%sfiles/comics/[^"]+)' % rurl))
+    imageSearch = compile(tagre("img", "src", r'(%sfiles/[^"]+)' % rurl))
     prevSearch = compile(tagre("a", "href", r'(%s[^"]+)' % rurl, after="prev"))
     help = 'Index format: yyyy/mm/dd/strip-name'
 
@@ -363,17 +355,13 @@ class AxeCop(_BasicScraper):
     url = 'http://axecop.com/'
     rurl = escape(url)
     starter = bounceStarter(url,
-        compile(tagre("a", "href", r'(%scomic/episode-\d+/)' % rurl, after="navi-next")))
-    stripUrl = url + 'comic/episode-%s/'
+        (
+          compile(tagre("a", "href", r'(%scomic/page-\d+-[^"]+/)' % rurl, after="nav-next")),
+          compile(tagre("a", "href", r'(%scomic/[^"]+/)' % rurl, after="nav-next")),
+        )
+    )
+    stripUrl = url + 'comic/%s/'
     firstStripUrl = stripUrl % '0'
     imageSearch = compile(tagre("img", "src", r'(http://mainsite\.axecop\.wpengine\.com/wp-content/uploads/sites/\d+/\d+/\d+/[^"]+)'))
-    prevSearch = compile(tagre("a", "href", r'(%scomic/episode-\d+/)' % rurl, after="navi-prev"))
-    help = 'Index format: number'
-
-    @classmethod
-    def namer(cls, imageUrl, pageUrl):
-        extension = imageUrl.rsplit('.', 1)[1]
-        episode = pageUrl.rsplit('-', 1)[1]
-        episode = episode.strip('/')
-        return 'AxeCop-%s.%s' % (episode, extension)
-
+    prevSearch = compile(tagre("a", "href", r'(%scomic/[^"]+/)' % rurl, after="nav-prev"))
+    help = 'Index format: usually stripname'
