@@ -2,7 +2,7 @@
 # Copyright (C) 2004-2005 Tristan Seligmann and Jonathan Jacobs
 # Copyright (C) 2012-2013 Bastian Kleineidam
 
-from re import compile, escape, IGNORECASE, MULTILINE
+from re import compile, escape, IGNORECASE
 
 from ..util import tagre
 from ..scraper import _BasicScraper
@@ -19,27 +19,6 @@ class FalconTwin(_BasicScraper):
     help = 'Index format: nnn'
 
 
-class Fallen(_BasicScraper):
-    baseUrl = 'http://www.fallencomic.com/'
-    url = baseUrl + 'fal-page.htm'
-    stripUrl = baseUrl + 'pages/part%s/%s-p%s.htm'
-    imageSearch = compile(r'<IMG SRC="(page/.+?)"', IGNORECASE)
-    prevSearch = compile(r'<A HREF="(.+?)"><FONT FACE="Courier">Back', IGNORECASE)
-    help = 'Index format: nn-m (comicNumber-partNumber)'
-    starter = indirectStarter(url,
-        compile(r'\(NEW \d{2}/\d{2}/\d{2}\)\s*\n*\s*<a href="(pages/part\d+/\d+-p\d+\.htm)">\d+</a>', MULTILINE))
-
-    @classmethod
-    def namer(cls, imageUrl, pageUrl):
-        num = pageUrl.split('/')[-1].split('-')[0]
-        part = pageUrl.split('-')[-1].split('.')[0]
-        return '%s-%s' % (part, num)
-
-    def getIndexStripUrl(self, index):
-        index, part = index.split('-')
-        return self.stripUrl % (part, index, part)
-
-
 class FantasyRealms(_BasicScraper):
     description = u'Fantasy Realms'
     url = 'http://www.fantasyrealmsonline.com/'
@@ -155,7 +134,7 @@ class Footloose(_BasicScraper):
 
 class ForLackOfABetterComic(_BasicScraper):
     url = 'http://forlackofabettercomic.com/'
-    rurl = escape(url)
+    rurl = r'http://(?:www\.)?forlackofabettercomic\.com/'
     stripUrl = url + '?id=%s'
     firstStripUrl = stripUrl % '1'
     imageSearch = compile(tagre("img", "src", r'(%simg/comic/\d+[^"]+)' % rurl, after="comicimg"))
