@@ -18,16 +18,6 @@ class IAmArg(_BasicScraper):
     help = 'Index format: yyyy/mm/dd/stripname'
 
 
-class IanJay(_BasicScraper):
-    url = 'http://ianjay.net/'
-    rurl = escape(url)
-    stripUrl = url + '?p=%s'
-    firstStripUrl = stripUrl % '210'
-    imageSearch = compile(tagre("img", "src", r'(%scomics/\d+[^"]+)' % rurl))
-    prevSearch = compile(tagre("a", "href", r'(%s\?p=\d+)' % rurl, after="Previous"))
-    help = 'Index foramt: nnn'
-
-
 class ICanBarelyDraw(_BasicScraper):
     url = 'http://www.icanbarelydraw.com/comic/'
     rurl = escape(url)
@@ -48,16 +38,6 @@ class IDreamOfAJeanieBottle(_BasicScraper):
     help = 'Index format: n (unpadded)'
 
 
-class InsideOut(_BasicScraper):
-    description = u'Inside Out Comic - A new kind of Weird'
-    url = 'http://www.insideoutcomic.com/'
-    stripUrl = url + 'html/%s.html'
-    firstStripUrl = stripUrl % '1_snake_suicide'
-    imageSearch = compile(r'Picture12LYR.+?C="(.+?/assets/images/.+?)"')
-    prevSearch = compile(r'Picture7LYR.+?F="(.+?/html/.+?)"')
-    help = 'Index format: n_comic_name'
-
-
 class IrregularWebcomic(_BasicScraper):
     url = 'http://www.irregularwebcomic.net/'
     stripUrl = url + '%s.html'
