@@ -2,7 +2,7 @@
 # Copyright (C) 2004-2005 Tristan Seligmann and Jonathan Jacobs
 # Copyright (C) 2012-2013 Bastian Kleineidam
 
-from re import compile
+from re import compile, escape
 from ..scraper import _BasicScraper
 from ..util import tagre
 
@@ -10,14 +10,18 @@ from ..util import tagre
 class QuestionableContent(_BasicScraper):
     url = 'http://www.questionablecontent.net/'
     stripUrl = url + 'view.php?comic=%s'
+    firstStripUrl = stripUrl % '1'
     imageSearch = compile(tagre("img", "src", r'([^"]+/comics/[^"]+)', before="strip"))
     prevSearch = compile(tagre("a", "href", r'(view\.php\?comic=\d+)') + 'Previous')
     help = 'Index format: n (unpadded)'
 
 
 class Qwantz(_BasicScraper):
-    url = 'http://www.qwantz.com/index.php'
+    baseUrl = 'http://www.qwantz.com/'
+    url = baseUrl + 'index.php'
+    rurl = escape(baseUrl)
     stripUrl = url + '?comic=%s'
-    imageSearch = compile(tagre("img", "src", r'(http://www\.qwantz\.com/comics/[^"]+)'))
-    prevSearch = compile(tagre("a", "href", r'(http://www\.qwantz\.com/index\.php\?comic=\d+)', before="prev"))
+    firstStripUrl = stripUrl % '1'
+    imageSearch = compile(tagre("img", "src", r'(%scomics/[^"]+)' % rurl))
+    prevSearch = compile(tagre("a", "href", r'(%sindex\.php\?comic=\d+)' % rurl, before="prev"))
     help = 'Index format: n'
