@@ -2,7 +2,7 @@
 # Copyright (C) 2004-2005 Tristan Seligmann and Jonathan Jacobs
 # Copyright (C) 2012-2013 Bastian Kleineidam
 
-from re import compile, escape, MULTILINE, IGNORECASE, sub
+from re import compile, escape, IGNORECASE, sub
 from os.path import splitext
 from ..scraper import _BasicScraper
 from ..helpers import indirectStarter, bounceStarter
@@ -35,7 +35,6 @@ class SailorsunOrg(_BasicScraper):
     stripUrl = url + '?p=%s'
     firstStripUrl = stripUrl % '21'
     imageSearch = compile(tagre("img", "src", r'(%scomics/[^"]+)' % rurl))
-    rurl = escape(url)
     prevSearch = compile(tagre("a", "href", r'(%s\?p=\d+)' % rurl, after="prev"))
     help = 'Index format: n (unpadded)'
 
@@ -95,8 +94,13 @@ class ScenesFromAMultiverse(_BasicScraper):
     rurl = escape(url)
     stripUrl = url + '%s/'
     firstStripUrl = stripUrl % '2010/06/14/parenthood'
-    imageSearch = compile(tagre("img", "src", r'(%sfiles/comics/[^"]+)' % rurl))
-    prevSearch = compile(tagre("a", "href", r'(%s\d+\d+/\d+/\d+/[^"]+)' % rurl, after="prev"))
+    imageSearch = (
+      compile(tagre("div", "id", "comic") + r"\s*" +
+        tagre("img", "src", r'(%swp-content/uploads/\d+/\d+/[^"]+)' % rurl)),
+      compile(tagre("div", "id", "comic") + r"\s*" + tagre("a", "href", r'[^"]*') +
+        tagre("img", "src", r'(%swp-content/uploads/\d+/\d+/[^"]+)' % rurl)),
+    )
+    prevSearch = compile(tagre("a", "href", r'(%scomic/\d+\d+/\d+/\d+/[^"]+)' % rurl, after="prev"))
     help = 'Index format: yyyy/mm/dd/stripname'
 
 
@@ -216,8 +220,8 @@ class Shivae(_BasicScraper):
     rurl = escape(url)
     stripUrl = url + 'blog/%s/'
     firstStripUrl = stripUrl % '2007/09/21/09212007'
-    imageSearch = compile(tagre("img", "src", r'(%sfiles/comics/[^"]+)' % rurl))
-    prevSearch = compile(tagre("a", "href", r'(%sblog/[^"]+)' % rurl, after="Previous"))
+    imageSearch = compile(tagre("img", "src", r'(%swp-content/blogs\.dir/\d+/files/\d+/\d+/[^"]+)' % rurl))
+    prevSearch = compile(tagre("a", "href", r'(%sblog/[^"]+)' % rurl, after="navi-prev"))
     help = 'Index format: yyyy/mm/dd/stripname'
 
 
@@ -350,7 +354,7 @@ class SnowFlame(_BasicScraper):
     rurl = escape(url)
     stripUrl = url + '?comic=snowflame-%s-%s'
     firstStripUrl = stripUrl % ('01', '01')
-    imageSearch = compile(tagre("img", "src", r'(%swp-content/uploads/\d+/\d+/[^"]+)' % rurl, after="Snow[Ff]lame the fan made"))
+    imageSearch = compile(tagre("img", "src", r'(%swp-content/uploads/\d+/\d+/[^"]+)' % rurl, after="Snow[Ff]lame "))
     prevSearch = compile(tagre("span", "class", "mininav-prev") +
         tagre("a", "href", r'(%s\?comic=snowflame[^"]+)' % rurl))
     starter = bounceStarter(url,
@@ -427,10 +431,10 @@ class SpareParts(_BasicScraper):
 class Spinnerette(_BasicScraper):
     url = 'http://www.spinnyverse.com/'
     rurl = escape(url)
-    stripUrl = url + '%s/'
+    stripUrl = url + 'index.php?id=%s'
     firstStripUrl = stripUrl % '2010/02/09/02092010'
-    imageSearch = compile(tagre("img", "src", r'(%scomics/[^"]+)' % rurl))
-    prevSearch = compile(tagre("a", "href", r'(%s[^"]+)' % rurl, before="Previous Comic"))
+    imageSearch = compile(tagre("img", "src", r'(comics/[^"]+)', after="comic"))
+    prevSearch = compile(tagre("a", "href", r'(/index\.php\?id=[^"]+)', after="prev"))
     help = 'Index format: number'
 
 
