@@ -18,6 +18,7 @@ class xkcd(_BasicScraper):
     prevSearch = compile(tagre("a", "href", r'(/\d+/)', before="prev"))
     help = 'Index format: n (unpadded)'
     description = u'A webcomic of romance, sarcasm, math, and language.'
+    textSearch = compile(tagre("img", "title", r'([^"]+)', before=r'http://imgs\.xkcd\.com/comics/'))
     adult = True
 
     @classmethod
@@ -25,3 +26,9 @@ class xkcd(_BasicScraper):
         index = int(pageUrl.rstrip('/').rsplit('/', 1)[-1])
         name = imageUrl.rsplit('/', 1)[-1].split('.')[0]
         return '%03d-%s' % (index, name)
+
+    @classmethod
+    def imageUrlModifier(cls, url, data):
+        if url and '/large/' in data:
+            return url.replace(".png", "_large.png")
+        return url
