@@ -5,8 +5,8 @@ import requests
 import time
 import os
 from . import loader, configuration
-from .util import (fetchUrl, fetchUrls, getPageContent, makeSequence,
-  get_system_uid, urlopen, getDirname)
+from .util import (fetchUrl, fetchUrls, fetchText, getPageContent,
+  makeSequence, get_system_uid, urlopen, getDirname, unescape)
 from .comic import ComicStrip
 from .output import out
 from .events import getHandler
@@ -66,6 +66,10 @@ class _BasicScraper(object):
     # this can also be a list or tuple of compiled regular expressions
     imageSearch = None
 
+    # compiled regular expression to store a text together with the image
+    # sometimes comic strips have additional text info for each comic
+    textSearch = None
+
     # usually the index format help
     help = ''
 
@@ -107,7 +111,10 @@ class _BasicScraper(object):
     def getComicStrip(self, url, data, baseUrl):
         """Get comic strip downloader for given URL and data."""
         imageUrls = fetchUrls(url, data, baseUrl, self.imageSearch)
-        imageUrls = set(map(self.imageUrlModifier, imageUrls))
+        # map modifier function on image URLs
+        imageUrls = [self.imageUrlModifier(x, data) for x in imageUrls]
+        # remove duplicate URLs
+        imageUrls = set(imageUrls)
         if len(imageUrls) > 1 and not self.multipleImagesPerStrip:
             patterns = [x.pattern for x in makeSequence(self.imageSearch)]
             out.warn(u"found %d images instead of 1 at %s with patterns %s" % (len(imageUrls), url, patterns))
@@ -117,7 +124,13 @@ class _BasicScraper(object):
         elif not imageUrls:
             patterns = [x.pattern for x in makeSequence(self.imageSearch)]
             out.warn(u"found no images at %s with patterns %s" % (url, patterns))
-        return ComicStrip(self.getName(), url, imageUrls, self.namer, self.session)
+        if self.textSearch:
+            text = fetchText(url, data, self.textSearch)
+            if text:
+                text = unescape(text).strip()
+        else:
+            text = None
+        return ComicStrip(self.getName(), url, imageUrls, self.namer, self.session, text=text)
 
     def getStrips(self, maxstrips=None):
         """Get comic strips."""
@@ -131,6 +144,9 @@ class _BasicScraper(object):
                 msg += u" for index %s" % self.indexes[0]
             else:
                 msg += u" for indexes %s" % self.indexes
+            # Always call starter() since it might initialize cookies.
+            # See for example Oglaf comic.
+            self.starter()
             urls = [self.getIndexStripUrl(index) for index in self.indexes]
         else:
             urls = [self.getLatestUrl()]
@@ -221,10 +237,10 @@ class _BasicScraper(object):
         return prevUrl
 
     @classmethod
-    def imageUrlModifier(cls, imageUrl):
+    def imageUrlModifier(cls, imageUrl, data):
         """Optional modification of parsed image URLs. Useful if the URL
         needs to be fixed before usage. The default implementation does
-        not modify the URL.
+        not modify the URL. The given data is the URL page data.
         """
         return imageUrl
 
