@@ -19,6 +19,7 @@ import sys
 import os
 import cgi
 import re
+import codecs
 import traceback
 import time
 import subprocess
@@ -246,10 +247,20 @@ def fetchUrls(url, data, baseUrl, urlSearch):
 
 
 def fetchUrl(url, data, baseUrl, urlSearch):
-    """Search first entry for given URL pattern in a HTML page."""
+    """Search first URL entry for given URL pattern in a HTML page."""
     return fetchUrls(url, data, baseUrl, urlSearch)[0]
 
 
+def fetchText(url, data, textSearch):
+    """Search text entry for given text pattern in a HTML page."""#
+    match = textSearch.search(data)
+    if match:
+        text = match.group(1)
+        out.debug(u'matched text %r with pattern %s' % (text, textSearch.pattern))
+        return text
+    raise ValueError("Pattern %s not found at URL %s." % (textSearch.pattern, url))
+
+
 _htmlparser = HTMLParser()
 def unescape(text):
     """Replace HTML entities and character references."""
@@ -555,3 +566,31 @@ def strlimit (s, length=72):
 def getLangName(code):
     """Get name of language specified by ISO 693-1 code."""
     return Iso2Language[code]
+
+
+def writeFile(filename, content, encoding=None):
+    """Write content to given filename. Checks for zero-sized files.
+    If encoding is given writes to a codec.open() file."""
+    if not content:
+        raise OSError("empty content for file %s" % filename)
+
+    def getfp(filename, encoding):
+        """Get open file object."""
+        if encoding:
+            return codecs.open(filename, 'w', encoding)
+        return open(filename, 'wb')
+
+    try:
+        with getfp(filename, encoding) as fp:
+            fp.write(content)
+            fp.flush()
+            os.fsync(fp.fileno())
+            size = os.path.getsize(filename)
+            if size == 0:
+                raise OSError("empty file %s" % filename)
+    except Exception:
+        if os.path.isfile(filename):
+            os.remove(filename)
+        raise
+    else:
+        out.info(u"Saved %s (%s)." % (filename, strsize(size)))
