@@ -290,6 +290,7 @@ exclude_comics = [
     "TheDevilsPanties", # page moved
     "TheDoctorPepperShow", # page has 403 forbidden
     "TheFantasticalBestiary", # page has 403 forbidden
+    "TheGreenAvenger", # missing images
     "TheGodsPack", # page has 403 forbidden
     "TheMadBrothers", # page does not follow standard layout
     "TheMediocres", # missing images
@@ -400,7 +401,7 @@ def handle_url(url, session, res):
             else:
                 check_robotstxt(url, session)
         except IOError:
-            print("INFO: robots.txt denied for", repr(name))
+            print("INFO: robots.txt denied for comicgenesis", repr(name))
             continue
         else:
             res[name] = (url, num)
