@@ -6,15 +6,17 @@ import shutil
 import re
 import os
 import multiprocessing
-import urlparse
-from itertools import islice
+try:
+    from urllib.parse import urlsplit
+except ImportError:
+    from urlparse import urlsplit
 from unittest import TestCase
 from dosagelib import scraper
 
 
 def get_host(url):
     """Get host part of URL."""
-    return urlparse.urlsplit(url)[1].lower()
+    return urlsplit(url)[1].lower()
 
 
 # Dictionary with per-host locks.
@@ -46,10 +48,13 @@ class _ComicTester(TestCase):
         if self.tmpdir is not None:
             shutil.rmtree(self.tmpdir)
 
-    def get_saved_images(self):
+    def get_saved_images(self, filtertxt=False):
         """Get saved images."""
         dirs = tuple(self.name.split('/'))
-        return os.listdir(os.path.join(self.tmpdir, *dirs))
+        files = os.listdir(os.path.join(self.tmpdir, *dirs))
+        if filtertxt:
+            files = [x for x in files if not x.endswith(".txt")]
+        return files
 
     def test_comic(self):
         if self.scraperclass is None:
@@ -98,7 +103,7 @@ class _ComicTester(TestCase):
     def check_scraperesult(self, num_images_expected, strip, scraperobj):
         # Check that exactly or for multiple pages at least num_strips images are saved.
         # This checks saved files, ie. it detects duplicate filenames.
-        saved_images = self.get_saved_images()
+        saved_images = self.get_saved_images(filtertxt=bool(scraperobj.textSearch))
         num_images = len(saved_images)
         # subtract the number of skipped URLs with no image from the expected image number
         attrs = (num_images, saved_images, num_images_expected, self.tmpdir)
@@ -137,12 +142,17 @@ def make_comic_tester(name, **kwargs):
 def generate_comic_testers():
     """For each comic scraper, create a test class."""
     g = globals()
-    if "TESTALL" not in os.environ:
-        # Get limited number of scraper tests on Travis builds.
-        max_scrapers = 1
-        scraperclasses = islice(scraper.get_scraperclasses(), 0, max_scrapers)
-    else:
+    if "TESTALL" in os.environ:
+        # test all comics (this will take some time)
         scraperclasses = scraper.get_scraperclasses()
+    else:
+        # Get limited number of scraper tests on Travis builds to make
+        # it faster
+        testscrapernames = ['GoComics/CalvinandHobbes']
+        scraperclasses = [
+            scraperclass for scraperclass in scraper.get_scraperclasses()
+            if scraperclass.getName() in testscrapernames
+        ]
     for scraperclass in scraperclasses:
         name = 'Test'+scraperclass.__name__
         g[name] = make_comic_tester(name, scraperclass=scraperclass)
